/*
Inside Night Mud Mountain
Author: Dan (dan@dantom.com)
Version:  1.0  (29-June-2000)

These are the caverns on the inside of the Night Mountain.

*/

#include <Dan/Maze>
#include <Dan/Mud>

//#define DEBUG
#ifdef DEBUG
#define debug world.log
#else
#define debug 0
#endif

var
	NumPlayers
	Maze/maze
	ReturnAddr = "byond://Dan.NightMud"

world
	turf = /turf/rock

	maxx = 30
	maxy = 30
	maxz = 2

world/New()
	var/Level = text2num(params["level"])
	if(Level <= 0) Level = 1

	if(params["return_addr"])
		ReturnAddr = params["return_addr"]

	maze = new()
	maze.TunnelType = /turf/tunnel
	maze.RoomType = /turf/floor
	maze.WallType = /turf/rock
	maze.Initialize(locate(2,2,1),locate(world.maxx-2,world.maxy-2,2),Level)

Mud/LoadPlayer(mob/P)
	. = ..()
	if(. && P.died)
		P.GotoAfterlife()

mob/Login()
	//check for save file
	if(!usr.loc)
		if(!mud.LoadPlayer(usr)) //new player
			usr << "You are not recognized here.  Make a new player first..."
			usr << link(ReturnAddr)
			del usr

	usr << "Welcome to the caves of Night Mountain."
	NumPlayers++
	if(NumPlayers > 1)
		world << "There are [NumPlayers] adventurers in the caves."

	if(!usr.loc) UsrGotozLevel(maze.Level,/turf/altar)

mob/Logout()
	if(key) //disconnect vs. mob change
		NumPlayers--
	..() //logout first so we don't get double logout
	if(key)
		mud.StorePlayer(usr)

mob/verb/meditate()
	var/old_loc = usr.loc
	if(usr.enemy)
		usr << "You are not nearly calm enough to concentrate."
		return

	view() << "[usr] begins to meditate."
	sleep(50)
	if(usr.loc != old_loc) return
	usr << "The voice of your master sounds in the distance..."
	sleep(50)
	if(usr.loc != old_loc) return
	usr << "Your soul floats free at last!"
	oview() << "[usr] fades from sight."

	usr << "You may return to the <a href='[ReturnAddr]'>center of the universe</a> at will."
	Logout()

mob/GotoAfterlife()
	if(usr.loc)  //don't save when player is logging in
		usr.died = 1
		mud.SavePlayer(usr)
	..()


Maze/GenLevel(Loc0,Loc1,Level)
	..()

	ReplaceATurfInBlock(/turf/tunnel, /turf/downstairs, Loc0, Loc1)
	ReplaceATurfInBlock(/turf/tunnel, /turf/altar, Loc0, Loc1)
	if(Level>1)  //No upstairs on first level
		ReplaceATurfInBlock(/turf/tunnel, /turf/upstairs, Loc0, Loc1)


	PopulateBlock(Loc0,Loc1,Level)


proc/PopulateBlock(turf/Loc0,turf/Loc1,Level)
	var
		Nmob = NumPlayers
		Nobj = NumPlayers
		Type
		turf/T
		mob/M


	if(!Nmob) Nmob = 1
	if(!Nobj) Nobj = 1
	Nmob *= round(0.01 * (Loc1.x-Loc0.x+1)*(Loc1.y-Loc0.y+1)*(Loc1.z-Loc0.z+1))
	Nobj *= round(0.01 * (Loc1.x-Loc0.x+1)*(Loc1.y-Loc0.y+1)*(Loc1.z-Loc0.z+1))

	//populate mobs
	debug << "creating [Nmob] mobs"
	while(Nmob--)
		Type = world.MobTable(Level)
		T = LocateATurfInBlock(/turf/floor,Loc0,Loc1)
		M = new Type(T)

		//create mob's treasure
		T=rand(M.rand_items)
		while(T-- && Nobj--)
			Type = world.ObjTable(Level)
			new Type(M)

	//populate objs
	debug << "creating [Nobj] objs"
	while(Nobj-- > 0)
		Type = world.ObjTable(Level)
		T = LocateATurfInBlock(/turf/floor,Loc0,Loc1)
		new Type(T)

turf/altar
	text = "**ooo"
	density = 0

	verb
		kneel()
			usr.step_mode = SIT_STEP
			view() << "[usr] kneels before [src]."
			sleep(200 + usr.karma)
			if(usr && usr.loc == src)
				usr << "The gift of prescience has been granted to you!"
				new/obj/Food/fortune_cookie(usr.loc)


		my_name(T as text)
			set name = "my name"
			if(usr.karma > 0) usr << "You must clear the sin of your old name first."
			else usr.SetName(T)

		my_description(T as text)
			set name = "my description"
			if(usr.karma > 0) usr << "You must clear your tarnished image first."
			else usr.desc = T

		my_gender(G in list("female","male","neuter"))
			set name = "my gender"
			if(usr.karma > 0)
				usr << "You must clear your tarnished image first."
				return

			usr.gender = G

	Enter(O)
		if(istype(O,/obj/Food) && usr)
			usr.AddKarma(-O:karma)
		return ..()

	Exit(O)
		if(istype(O,/obj/Food) && usr)
			usr.AddKarma(2*O:karma)
		return ..()

client
	Center()
		var/obj/O
		var/i
		var/turf/T = usr.loc

		for(i=T.contents.len;i;i--)
			O = T.contents[i]
			if(!isobj(O)) continue

			O.get() //pick up top object
			return

		T.Use()

world/UsrUpLevel()
	var/l = maze.GetLevel(usr.z) - 1
	var/z
	if(l > 0) z = maze.GetzLevel(l)

	if(z)
		UsrGotozLevel(z,/turf/downstairs)
		return 1

	else usr << "Your passage is frozen solid."

world/UsrDownLevel()
	var/l = maze.GetLevel(usr.z) + 1
	var/z = maze.GetzLevel(l)

	if(z)
		UsrGotozLevel(z,/turf/upstairs)
		return 1

	else usr << "Your passage is frozen solid."

proc/UsrGotozLevel(Z,Type)
	var/Loc = LocateTurfInBlock(Type,locate(1,1,Z),locate(world.maxx,world.maxy,Z))
	var/turf {L0; L1}
	L0 = locate(1,1,Z)
	L1 = locate(world.maxx,world.maxy,Z)
	if(!Loc) debug << "Failed to find [] in ([],[],[]) to ([],[],[])."(Type,L0.x,L0.y,L0.z,L1.x,L1.y,L1.z)
	if(!Loc || !usr.MoveNoBump(Loc))
		usr.MoveNoBump(LocateTurfInBlock(/turf/tunnel,locate(1,1,Z),locate(world.maxx,world.maxy,Z)))


turf/proc
	//to be defined by external code
	DestroyBlock() //replace this turf with a non-dense one
	CreateBlock()  //replace this turf with a dense one

world/proc
	//to be defined by external code

	UsrUpLevel()    //move usr up a z level (or return 0 on failure)
	UsrDownLevel()  //move usr down a z level (or return 0 on failure)

////////// turfs ///////////

turf
	tunnel
		text = " "
		density = 0

		CreateBlock() new/turf/rock(src)

	floor
		text = "."
		density = 0

	rock
		text = "#"
		opacity = 1
		density = 1

		DestroyBlock() new/turf/tunnel(src)

	downstairs
		text = ">"
		density = 0

		Use()
			world.UsrDownLevel()

		DeltaZOnUse()
			return 1

	upstairs
		text = "<"
		density = 0

		Use()
			world.UsrUpLevel()

		DeltaZOnUse()
			return -1
