/*
Night Soil MUD

This combines the Night Soil combat system with the BYOND MUD engine.  You
can use this as an example of how to add your own combat system to the
MUD.  Or, feel free to use this one.
*/

#include <Dan/Mud>
#include <Dan/NightSoil>
#include "objects.dm"
#include "social.dm"

Mud/New()
	..()
	src.basic_poptypes.Remove(
		typesof(/obj/Food/Corpse),
		typesof(/obj/Parasite)
	)

mob
	//override Night Soil movement procs which are for movement on a map
	StepAway(Trg,Dst)
		if(get_dist(Trg,Dst) == 0) src.StepRand()
	StepTo(mob/Trg,Dst)
		var/room/r1
		var/room/r2
		if(get_dist(Trg,Dst) == 0) return

		usr = src
		r1 = src.loc
		r2 = Trg.loc
		if(r1.north_exit == r2) return r1.north()
		if(r1.south_exit == r2) return r1.south()
		if(r1.east_exit == r2) return r1.east()
		if(r1.west_exit == r2) return r1.west()

		var/action/exit/e
		for(e in r1)
			if(e.dest == r2) return e.Action()
	StepRand()
		var/room/r = src.loc

		if(!istype(r,/room)) return
		usr = src
		pick(
			r:north(),
			r:south(),
			r:east(),
			r:west())
	StepExplore()
		src.StepRand()

mob/Repop()
	var/count
	for(count=0;count<src.rand_items;count++)
		var/obj/O = new(world.ObjTable(src.zlevel),src)
		O.Repop()

mob/Stat()
	if(src.loc && statpanel("View"))
		src.loc.Stat()
	..()

mob/GotoAfterlife()
	if(enemy) enemy.Peace()
	Peace()
	if(usr.loc)  //don't save when player is logging in
		died = 1
		mud.SavePlayer(src)
	..()

Mud/LoadPlayer(mob/P)
	. = ..()
	if(.)
		if(P.died) P.GotoAfterlife()

area/Afterlife/unincarnate()
	usr << "Your soul floats free.  Bye bye."
	mud.RemovePlayer(usr.key)
	usr.key = null //prevent savefile from getting generated on Logout
	del usr

area/Afterlife/reincarnate()
	if(usr.max_life/2 > usr.life) usr.life = usr.max_life/2
	if(usr.max_strength/2 > usr.max_strength) usr.strength = usr.max_strength/2
	if(usr.max_iq/2 > usr.max_iq) usr.iq = usr.max_iq/2
	usr.died = 0
	mud.GotoStart(usr)
