/*Night Mud Objects
  author: Dan of Dantom
  email:  dantom@dantom.com
  version 1  (12-Aug-1999)

  These are the object definitions used by nightmud.dm.  Most of them are
  simply copied from the objects used in the stool.dm Night Soil demo.
*/

#define FILE_DIR sounds

#include <Dan/NightSoil>

mob/step_lag = 60
world/proc {
	//there are defaults for these, but additional items can be included by re-defining these procs
	MobTable()
	ObjTable()
	WeaponTable()
	ArmorTable()
	ScrollTable()
	FoodTable()
}

world/mob = /mob/pc


/****** standard player verbs *******/
client/verb
	inventory()
		var/obj/O
		if(!usr.contents.len)
			usr << "You are not carrying anything."
			return
		usr << "You are carrying"
		for(O in usr)
			usr << O.name

/********** The Money System ***********/
obj/var/value
obj/proc/Value()
	return value
obj/Food/Value()
	. = ..()
	if(isnull(.))
		. = src.life + src.aim + src.strength + src.armor + src.iq + src.immunity - src.karma
		if(src.duration) . *= src.duration
		if(src.rot) . -= 100 * 2 ** (-src.rot/100)
obj/Food/salt/value = 5
obj/Configure(Name)
		..()
		value = input("Value",,value) as num
obj/DesignerInfo()
		..()
		usr << "value = [value]"

mob/proc/SubMoney(amount)
	var/obj/money/M = locate(/obj/money,src)
	if(M && M.value >= amount && amount >= 0)
		M.value -= amount
		return 1
mob/proc/AddMoney(amount)
	var/obj/money/M = locate(/obj/money,src)
	if(!M) M = new/obj/money(src)
	M.value += amount
obj/money
	name = "money"
	gender = "plural"
	Stat()
		..()
		stat("chips",value)
	verb/count()
		usr << "You count [value] chip\s."
	Move(Loc)
		if(Loc)
			var/obj/money/M = locate(/obj/money,Loc)
			if(M)
				M.value += value
				del(src)
				return
		return ..()

mob/verb/drop()
	set src in usr
	src.Move(usr.loc)

mob/Click() usr.look(src)
obj/Click() usr.look(src)
mob/verb/look(trg=usr.loc in view())
	if(istype(trg,/room))
		trg:Desc()
	else if(!trg:desc)
		usr << pick("You see \a [trg].","You see \a [trg], nothing more, nothing less.","[trg] exists here at this moment, or so it would seem.")
	else
		view() << "[usr] looks at [trg]."
		usr << trg:desc


mob {
	step_lag = 60
	swing_lag = 100
	var/zlevel //a measure of difficulty (the bigger the badder)
	pc {
		mood = CALM
		life = 2
		strength = 4
		aim = 2
		offense = 2
	}

	//////////level 1///////////
	rat {
		zlevel = 1

		life = 2
		strength = 1
		aim = 1
		armor = 1
		offense = 1.5
		rand_items = 2
		party_id = .rat
		karma = 2

		corpse = /obj/Food/Corpse/rat
		/obj/Food/Corpse/rat {
			life = 2
			parasite = /obj/Parasite/tapeworm
			parasite_prob = 30
			rot = 200
		}
		Answer(Text) {
			if(findtext(Text,"cheese")) {
				view() << "[src]'s nose twiches excitedly."
			}
		}
	}
	bat {
		zlevel = 1

		life = 2
		strength = 2
		aim = 3
		armor = 2

		offense = 1.5

		karma = 2

		corpse = /obj/Food/Corpse/bat
		/obj/Food/Corpse/bat {
			life = 4
			strength = 3
			iq = 2

			parasite = /obj/Parasite/tapeworm
			parasite_prob = 30
			rot = 200
		}
	}
	cat {
		zlevel = 1

		life = 9
		strength = 5
		aim = 5
		armor = 2

		offense = 1.5

		karma = 4
		party_id = .cat

		corpse = /obj/Food/Corpse/cat
		/obj/Food/Corpse/cat {
			life = 10
			strength = 7
			iq = 3

			parasite = /obj/Parasite/tapeworm
			parasite_prob = 10
			rot = 200
		}
	}
	spider {
		zlevel = 1

		life = 5
		strength = 4
		iq = 5
		aim = 4
		armor = 1

		offense = 1.5

		mood = CALM
		corpse = /obj/Food/Corpse/spider
		/obj/Food/Corpse/spider {
			life = 4
			strength = 1
			iq = 5

			rot = 500
		}
	}

	//////////level 3//////////
	hornet {
		zlevel = 3
		life = 5
		strength = 3
		aim = 2
		armor = 5

		offense = 2
		defense = 1.5

		immunity = 10

		mood = HOSTILE
		corpse = /obj/Food/Corpse/hornet
		/obj/Food/Corpse/hornet {
			life = -2
			strength = 2
			iq = 5

			immunity = 10
		}
	}
	thief {
		zlevel = 3

		life = 5
		strength = 5
		iq = 5
		aim = 1
		armor = 1

		karma = 5

		mood = HOSTILE
		corpse = /obj/Food/Corpse/thief
		/obj/Food/Corpse/thief {
			life = 5
			strength = 5
			iq = 5

			rot = 500
		}

		New() {
			src.StealTick()
			return ..()
		}
		proc/StealTick() {
			spawn for() {
				sleep(500)

				var/mob/M
				for(M as mob in oview(1)) {
					if(M.key && (src.party_id != M.party_id || src.rank>M.rank)) {
						if(M.contents.len) {
							var/obj/O
							O = M.contents[rand(1,M.contents.len)]
							O.Move(src)
							view() << "A smug look spreads across [src]'s face."
						}
					}
				}
			}
		}
	}

	/////////////level 6/////////////
	mountain_goat {
		zlevel = 6
		life = 10
		strength = 10
		iq = 5
		aim = 15
		armor = 5

		karma = 5
		rand_items = 1

		corpse = /obj/Food/Corpse/mountain_goat
		/obj/Food/Corpse/mountain_goat {
			life = 15
			strength = 15
			iq = 5

			rot = 500
		}
	}
	yeti {
		zlevel = 6
		life = 10
		strength = 15
		iq = 5
		aim = 10
		armor = 15

		karma = 5
		rand_items = 1

		mood = HOSTILE
		step_mode = RAND_STEP
		corpse = /obj/Food/Corpse/yeti
		/obj/Food/Corpse/yeti {
			life = 20
			strength = 20
			iq = 5

			rot = 500
		}
	}
	wizard {
		zlevel = 6

		life = 10
		strength = 10
		iq = 10
		aim = 1
		armor = 1

		karma = 10

		corpse = /obj/Food/Corpse/wizard
		/obj/Food/Corpse/wizard {
			life = 10
			strength = 10
			iq = 10

			rot = 500
		}
	}
	crank {
		zlevel = 6

		life = 10
		strength = 10
		iq = 10
		aim = 15
		armor = 10

		karma = 10
		rand_items = 2
		party_id = .crank
		mood = HOSTILE

		corpse = /obj/Food/Corpse/crank
		/obj/Food/Corpse/crank {
			life = 10
			strength = 10
			iq = 10

			rot = 500
		}
	}
	dwarf {
		zlevel = 6

		life = 10
		strength = 10
		iq = 5
		aim = 10
		armor = 20

		karma = 5
		rand_items = 1

		corpse = /obj/Food/Corpse/dwarf
		/obj/Food/Corpse/dwarf {
			life = 15
			strength = 15
			iq = 5

			rot = 500
		}
	}
	barbarian {
		zlevel = 6

		life = 10
		strength = 15
		iq = 5
		aim = 10
		armor = 15

		karma = 5
		rand_items = 1

		mood = HOSTILE
		corpse = /obj/Food/Corpse/barbarian
		/obj/Food/Corpse/barbarian {
			life = 20
			strength = 20
			iq = 5

			rot = 500
		}
	}
	goblin {
		zlevel = 6

		life = 10
		strength = 10
		iq = 5
		aim = 10
		armor = 20

		karma = 2
		rand_items = 1

		mood = HOSTILE
		corpse = /obj/Food/Corpse/goblin
		/obj/Food/Corpse/goblin {
			life = 10
			strength = 5
			iq = 20

			rot = 500
		}
	}
	centaur {
		zlevel = 6

		life = 10
		strength = 15
		iq = 5
		aim = 15

		karma = 10
		rand_items = 1
		party_id = .centaur

		corpse = /obj/Food/Corpse/centaur
		/obj/Food/Corpse/centaur {
			life = 10
			strength = 15
			iq = 5

			rot = 500
		}
	}
	blue_meanie {
		zlevel = 6

		life = 10
		strength = 10
		iq = 10
		aim = 15

		karma = 10
		rand_items = 1
		party_id = .crank

		mood = HOSTILE
		corpse = /obj/Food/Corpse/blue_meanie
		/obj/Food/Corpse/blue_meanie {
			life = 10
			strength = 5
			iq = 15

			rot = 500
		}
	}
	rataman {
		zlevel = 6

		life = 10
		strength = 10
		iq = 10
		aim = 15

		karma = 5
		rand_items = 1
		party_id = .rataman

		mood = HOSTILE
		corpse = /obj/Food/Corpse/rataman
		/obj/Food/Corpse/rataman {
			life = 10
			strength = 5
			iq = 15

			parasite = /obj/Parasite/tapeworm
			parasite_prob = 50
			rot = 200
		}
	}
	skeleton {
		zlevel = 6

		life = 5
		strength = 15
		iq = 10
		aim = 5

		karma = 5
		rand_items = 1
		party_id = .skeleton

		corpse = /obj/Food/Corpse/skeleton
		/obj/Food/Corpse/skeleton {
			life = 10
			iq = 15
		}
	}

	/////////////level 11////////////
	wizard2 {
		zlevel = 11

		life = 15
		strength = 15
		iq = 15

		karma = 15

		corpse = /obj/Food/Corpse/wizard2
		/obj/Food/Corpse/wizard2 {
			life = 15
			strength = 15
			iq = 15

			rot = 500
		}
	}
	elf {
		zlevel = 11

		life = 15
		strength = 10
		iq = 20
		aim = 15
		armor = 10

		immunity = 5
		karma = 10
		rand_items = 1
		party_id = .elf

		corpse = /obj/Food/Corpse/elf
		/obj/Food/Corpse/elf {
			life = 20
			strength = 15
			iq = 10

			rot = 500
		}
	}
	crank2 {
		zlevel = 11

		name = "crank"
		life = 20
		strength = 20
		iq = 20
		aim = 20

		karma = 20
		rand_items = 3
		party_id = .crank

		corpse = /obj/Food/Corpse/crank
		/obj/Food/Corpse/crank {
			life = 20
			strength = 20
			iq = 20

			rot = 500
		}
	}
	barbarian2 {
		zlevel = 11

		name = "barbarian"
		life = 25
		strength = 25
		iq = 10
		aim = 15
		armor = 20

		offense = 2
		defense = 2

		karma = 10
		rand_items = 2

		mood = HOSTILE
		corpse = /obj/Food/Corpse/barbarian2
		/obj/Food/Corpse/barbarian2 {
			life = 30
			strength = 25
			iq = 10

			parasite = /obj/Parasite/ringworm
			parasite_prob = 20
			rot = 200
		}
	}
	scorpion {
		zlevel = 11

		life = 10
		strength = 3
		aim = 10
		armor = 5

		offense = 3
		defense = 1.5

		immunity = 10

		corpse = /obj/Food/Corpse/scorpion
		/obj/Food/Corpse/scorpion {
			life = 2
			strength = 5
			iq = 10

			immunity = 10
		}
	}
	wolf {
		zlevel = 11

		life = 20
		strength = 15
		aim = 15
		armor = 5

		offense = 3

		karma = 4
		party_id = .wolf

		corpse = /obj/Food/Corpse/wolf
		/obj/Food/Corpse/wolf {
			life = 25
			strength = 25
			iq = 5

			rot = 500
		}
	}
	goblin2 {
		zlevel = 11

		name = "goblin"
		life = 25
		strength = 35
		iq = 10
		aim = 15
		armor = 25

		karma = 5
		rand_items = 1

		mood = HOSTILE
		corpse = /obj/Food/Corpse/goblin2
		/obj/Food/Corpse/goblin2 {
			life = 20
			strength = 5
			iq = 30

			rot = 500
		}
	}
	blue_meanie2 {
		zlevel = 11

		name = "blue meanie"
		life = 20
		strength = 15
		iq = 25
		aim = 15

		karma = 25
		rand_items = 1
		party_id = .crank

		mood = HOSTILE
		corpse = /obj/Food/Corpse/blue_meanie2
		/obj/Food/Corpse/blue_meanie2 {
			life = 25
			strength = 5
			iq = 30

			rot = 500
		}
	}
	rataman2 {
		zlevel = 11

		name = "rataman"
		life = 20
		strength = 20
		iq = 20
		aim = 15

		karma = 10
		rand_items = 1
		party_id = .rataman

		corpse = /obj/Food/Corpse/rataman2
		/obj/Food/Corpse/rataman2 {
			life = 20
			strength = 15
			iq = 25

			parasite = /obj/Parasite/ringworm
			parasite_prob = 25
			rot = 200
		}
	}

	/////////////level 21////////////
	warrior2 {
		zlevel = 21

		life = 25
		strength = 25
		iq = 25

		karma = 25

		corpse = /obj/Food/Corpse/warrior2
		/obj/Food/Corpse/warrior2 {
			life = 25
			strength = 25
			iq = 25

			rot = 500
		}
	}
	dwarf2 {
		zlevel = 21

		name = "dwarf"
		life = 30
		strength = 30
		iq = 10
		aim = 30
		armor = 30

		karma = 15
		rand_items = 1

		corpse = /obj/Food/Corpse/dwarf2
		/obj/Food/Corpse/dwarf2 {
			life = 40
			strength = 40
			iq = 15

			rot = 500
		}
	}
	centaur2 {
		zlevel = 21

		name = "centaur"
		life = 30
		strength = 30
		iq = 10
		aim = 20

		karma = 20
		rand_items = 1
		party_id = .centaur

		corpse = /obj/Food/Corpse/centaur2
		/obj/Food/Corpse/centaur2 {
			life = 30
			strength = 30
			iq = 10

			rot = 500
		}
	}
	ghost {
		zlevel = 21

		life = 25
		strength = 35
		iq = 10

		defense = 10

		karma = 5
		rand_items = 1

		mood = HOSTILE
		corpse = /obj/Food/Corpse/ghost
		/obj/Food/Corpse/ghost {
			life = 25
			strength = 5
			iq = 35
		}
	}
	zombie {
		zlevel = 21

		life = 15
		strength = 45
		iq = 30
		aim = 25

		karma = 20
		rand_items = 1
		party_id = .skeleton

		mood = HOSTILE
		corpse = /obj/Food/Corpse/zombie
		/obj/Food/Corpse/zombie {
			life = 10
			strength = 30
			iq = 50
		}
	}

	/////////////level 31//////////
	wizard3 {
		zlevel = 31

		life = 30
		strength = 30
		iq = 30

		karma = 30

		corpse = /obj/Food/Corpse/wizard3
		/obj/Food/Corpse/wizard3 {
			life = 30
			strength = 30
			iq = 30

			rot = 500
		}
	}
	blue_meanie3 {
		zlevel = 31

		name = "big blue meanie"
		life = 30
		strength = 25
		iq = 35
		aim = 25

		karma = 35
		rand_items = 2
		party_id = .crank

		corpse = /obj/Food/Corpse/blue_meanie3
		/obj/Food/Corpse/blue_meanie3 {
			life = 35
			strength = 15
			iq = 40

			rot = 500
		}
	}
	rataman3 {
		zlevel = 31

		name = "rataman"
		life = 30
		strength = 30
		iq = 30
		aim = 25

		karma = 20
		rand_items = 1
		party_id = .rataman

		corpse = /obj/Food/Corpse/rataman3
		/obj/Food/Corpse/rataman3 {
			life = 30
			strength = 25
			iq = 35

			parasite = /obj/Parasite/hookworm
			parasite_prob = 25
			rot = 200
		}
	}
	dragon {
		zlevel = 31

		life = 40
		strength = 40
		iq = 10
		aim = 25

		karma = 30
		rand_items = 1

		mood = HOSTILE
		corpse = /obj/Food/Corpse/rataman3
		/obj/Food/Corpse/dragon {
			life = 40
			strength = 40
			iq = 10
			rot = 500
		}
	}
	vampire {
		zlevel = 31

		life = 20
		strength = 40
		iq = 30
		aim = 25

		karma = 20
		rand_items = 1
		party_id = .skeleton

		mood = HOSTILE
		corpse = /obj/Food/Corpse/vampire
		/obj/Food/Corpse/vampire {
			life = 30
			strength = 20
			iq = 40

			parasite = /obj/Parasite/brainrot
			parasite_prob = 30
			rot = 200
		}
	}
}

obj/Parasite {
	tapeworm {
		life = 0.8
		strength = 0.8
	}
	ringworm {
		life = 0.7
		strength = 0.7
		aim = 0.8
	}
	hookworm {
		life = 0.6
		strength = 0.6
		aim = 0.7
		iq = 0.8
	}
	brainrot {
		iq = 0.1
	}
	acidworm {
		life = 0.8
		strength = 0.8
		Infect(mob/Host) {
			..(Host)
			Host.verbs.Add(.acidworm/proc/fart)
		}
		Del() {
			src.host.verbs.Remove(.acidworm/proc/fart)
		}
		proc/fart(mob/Trg as mob in oview(2)) {
			set name = "fart"
			view() << "[usr] blows an acid fart at [Trg]!"
			Trg.War(usr)
			Trg.AddLife(-5)
		}
	}
}


///////// Food /////////

obj/Food {
	text = "%"

	garlic {
		gender = "plural"
		immunity = 2
	}
	pickle {
		life = 10
	}
	white_mushroom {
		life = 5
	}
	green_mushroom {
		life = 2
		strength = -1
		iq = 10
	}
	shitake_mushroom {
		life = -5
		immunity = 20
	}
	brown_mushroom {
		life = 20
		strength = 20
		iq = -20
	}
	inky_mushroom {
		life = 20
		strength = -20
		iq = 20
	}
	red_mushroom {
		duration = 5
		delay = 100

		life = -30
		immunity = 50
	}
	fortune_cookie {
		life = 1
		iq = 20

		EatDesc() {
			..()
			usr << "You read the scrap of paper inside:"

			usr << pick(
				"Garlic is an excellent seasoning when the food refuses to die.",
				"Had a sudden attack of stupidity?  Could be brain rot.",
				"Salt won't cure the hunger of the living, but it does cure the dead admirably.",
				"He who would gain life must first loose it (but not too much, of course).",
				"Exercise and good gruel (in that order) are the keys to better health.",
				"A fine blade in the hands of a novice might as well be a bag of rocks.",
				"Heavy armor won't help if one is too clumsy to maneuver in it.",
				"A karmic debt in this life will be paid in the next (plus interest).",
				"Visions of another reality are not uncommon during lengthy meditations.",
				"Food that perishes quickly might attract unwanted company.")
		}
	}
	salt {
		name = "salt shaker"
		var/quantity = 10

		verb {
			sprinkle(obj/Food/O as obj in view(0)) {
				view() << "[usr] sprinkles a pinch of salt onto \an [O]."
				if(istype(O,/obj/Food) && O.rot) {
					O.rot -= 500
					if(O.rot < 0) O.rot = 0
				}
				if(--src.quantity <= 0) {
					usr << "That finished off [src]."
					del(src)
				}
			}
		}
	}
}


////////// Weapons ///////////

obj/Weapon {
	text = "("

	rock {
		aim = 2
	}
	club {
		aim = 4
	}
	whip {
		aim = 7
		offense = 1.1
	}
	dagger {
		aim = 7
		offense = 1.5
	}
	quarterstaff {
		aim = 9
		offense = 1.5
	}
	flail {
		aim = 10
		offense = 1.6
	}
	axe {
		aim = 10
		offense = 1.75
	}
	spear {
		aim = 12
		offense = 1.75
	}
	trident {
		aim = 15
		offense = 1.8
	}
	warhammer {
		aim = 20
		offense = 1.5
	}
	pick {
		aim = 5
		offense = 1.25
	}
	glaive {
		aim = 17
		offense = 1.9
	}
	lance {
		aim = 18
		offense = 2
	}
	mace {
		aim = 30
		offense = 2
	}
	poleaxe {
		aim = 20
		offense = 2.1
	}
	sword {
		aim = 40
		offense = 4
	}
	cutlass {
		aim = 25
		offense = 2.5
	}
	scimitar {
		aim = 30
		offense = 3
	}
}


////////// Armor //////////

obj/Armor {
	text = "\["

	plate {
		name = "plate male"
		gender = "plural"
		armor = 50
		defense = 2
	}
	chain {
		name = "chain male"
		gender = "plural"
		armor = 25
		defense = 1.5
	}
	leather {
		name = "leather armor"
		gender = "plural"
		armor = 10
	}
	cloak {
		armor = 5
	}
	shield {
		slot_name = " (on arm)"
		armor = 5
	}
	boots {
		gender = "plural"
		slot_name = " (on feet)"
		armor = 2
	}
	gloves {
		gender = "plural"
		slot_name = " (on hands)"
		armor = 1
	}
	helmet {
		slot_name = " (on head)"
		armor = 10
		defense = 1.2
	}
	gauntlets {
		slot_name = " (on hands)"
		armor = 5
		defense = 1.1
	}
}


///////// Scrolls /////////

obj/Scroll {
	text = "?"

	preserve {
		name = "preserve scroll"
		iq = 20
		read(obj/Food/O as obj in view(0)) {
			if(..()) {
				usr << "You irradiate [O]."
				if(istype(O,/obj/Food)) {
					if(!findtext(O.name,"preserves")) O.name = addtext(O.name," preserves")
					O.rot = 0
				}
			}
		}
	}
	scare {
		name = "scare scroll"
		CastDesc() {return "[usr] makes a scary sound."}

		read(mob/Trg as mob) {
			src.iq = Trg.iq
			if(..()) {
				Trg.mood = CHICKEN
				Trg.War(usr)
			}
		}
	}
	charm {
		name = "charm scroll"

		read(mob/Trg as mob) {
			src.iq = Trg.iq
			if(..()) {
				Trg.party_id = usr
				Trg.rank = -1
				Trg.step_trg = usr
				Trg.step_mode = TRACK_STEP
				view() << "[Trg] grovels at [usr]'s feet."

				//add Trg to control group
				var/mob/M
				Trg.group.len=0
				for(M in usr.group) {
					M.group.Add(Trg)
					Trg.group.Add(M)
				}
				Trg.group.Add(usr)
				usr.group.Add(Trg)
			}
			else Trg.War(usr)
		}
	}
	summon {
		name = "summon scroll"
		iq = 20

		read(mob/Trg as mob in world) {
			if(..()) {
				if(Trg.MoveNear(usr.loc))
					view() << "[usr] summons \a [Trg] from the mists."
				else
					usr << "There is no room for [Trg]!"
			}
		}
	}
	teleport {
		name = "teleport scroll"
		iq = 20

		read(mob/Trg as mob in world) {
			if(..()) {
				if(usr.MoveNear(Trg.loc)) {
					view() << 'arrp.wav'
					view() << "[usr] materializes."
				}
				else
					usr << "There is no room!"
			}
		}
	}
	transport {
		name = "transport scroll"
		iq = 40

		read(mob/Trg as mob in world) {
			if(..()) {
				if(usr.MoveNear(Trg.loc)) {
					view() << 'arrp.wav'
					view() << "[usr] materializes."

					var/mob/M
					for(M in usr.group) {
						M.MoveNear(usr)
						usr = M //move next mob near this one
						view() << "[usr] materializes."
					}
				}
				else
					usr << "There is no room!"
			}
		}
	}
	fire {
		name = "fire scroll"
		CastDesc() {return "Fire leaps from [usr]'s fingers."}
		iq = 5

		lightning {
			name = "lightning scroll"
			CastDesc() {return "Electricity arcs from [usr]'s hands."}
			iq = 10
		}
		lava {
			name = "lava scroll"
			CastDesc() {return "Lava pours from [usr]'s mouth!"}
			iq = 20
		}
		lazer {
			name = "lazer scroll"
			CastDesc() {return "[usr]'s eyes start to smoke."}
			iq = 30
		}
		read(mob/Trg as mob) {
			if(..()) {
				view() << 'boom.wav'
				missile(/obj/Image/Fire,usr,Trg.loc)
				sleep(4)
				if(!Trg) return //Trg died
				/obj/Image/Fire {
					text = "*"
				}

				Trg.War(usr)
				Trg.AddLife(-src.iq)
			}
		}
	}
}

////////// Tables //////////

world/WeaponTable(Level) {
	switch(Level) {
		if(1 to 3) return pick(
			/obj/Weapon/rock,
			/obj/Weapon/club,
			/obj/Weapon/whip,
			/obj/Weapon/dagger)

		if(4 to 5) return pick(
			prob(500); .(1),
			/obj/Weapon/quarterstaff,
			/obj/Weapon/flail)

		if(6 to 9) return pick(
			prob(5); .(4),
			/obj/Weapon/axe,
			/obj/Weapon/spear)

		if(10 to 14) return pick(
			.(6),
			/obj/Weapon/trident,
			/obj/Weapon/warhammer)

		if(15 to 19) return pick(
			.(10),
			/obj/Weapon/pick,
			/obj/Weapon/glaive)

		if(20 to 24) return pick(
			.(15),
			/obj/Weapon/lance,
			/obj/Weapon/mace)

		if(25 to 29) return pick(
			.(20),
			/obj/Weapon/poleaxe,
			/obj/Weapon/cutlass)

		else return pick(
			.(25),
			/obj/Weapon/scimitar,
			/obj/Weapon/sword)

	}
}
world/ScrollTable(Level) {
	switch(Level) {
		if(1,2) return pick(
			/obj/Scroll/scare,
			/obj/Scroll/preserve)

		if(3,4) return pick(
			.(1),
			/obj/Scroll/fire,
			/obj/Scroll/teleport)

		if(5 to 9) return pick(
			.(3),
			/obj/Scroll/fire/lightning,
			/obj/Scroll/summon)

		if(10 to 14) return pick(
			.(5),
			/obj/Scroll/fire/lava,
			/obj/Scroll/transport)

		if(15 to 19) return pick(
			.(10),
			/obj/Scroll/fire/lazer)

		else return pick(
			.(15),
			/obj/Scroll/charm)

	}
}
world/ArmorTable(Level) {
	switch(Level) {
		if(1 to 4) return pick(
			/obj/Armor/cloak,
			/obj/Armor/shield,
			/obj/Armor/boots,
			/obj/Armor/gloves)

		if(5 to 9) return pick(
			.(1),
			/obj/Armor/leather,
			/obj/Armor/helmet)

		if(10 to 15) return pick(
			.(5),
			/obj/Armor/chain,
			/obj/Armor/gauntlets)

		else return pick(
			.(10),
			/obj/Armor/plate)

	}
}
world/FoodTable(Level) {
	switch(Level) {
		if(1 to 4) return pick(
			/obj/Food/fortune_cookie,
			/obj/Food/garlic,
			/obj/Food/salt,
			/obj/Food/white_mushroom,
			/obj/Food/green_mushroom)

		if(5 to 9) return pick(
			.(1),
			/obj/Food/shitake_mushroom,
			/obj/Food/brown_mushroom,
			/obj/Food/inky_mushroom)

		else return pick(
			.(5),
			/obj/Food/red_mushroom)

	}
}

world/ObjTable(Level) {
	return pick(
		world.WeaponTable(Level),
		world.ArmorTable(Level),
		world.ScrollTable(Level),
		world.FoodTable(Level))
}
world/MobTable(Level) {
	switch(Level) {
		if(1 to 2) return pick(
			/mob/rat,
			/mob/bat,
			/mob/cat,
			/mob/spider,
			prob(25); /mob/hornet,
			prob(25); /mob/thief)

		if(3 to 5) return pick(
			.(2),
			/mob/hornet,
			/mob/thief)

		if(6 to 10) return pick(
			prob(500); .(5),
			/mob/wizard,
			/mob/crank,
			/mob/dwarf,
			/mob/barbarian,
			/mob/goblin,
			/mob/centaur,
			/mob/blue_meanie,
			/mob/rataman,
			/mob/skeleton)

		if(11 to 20) return pick(
			prob(300); .(5),
			prob(300); .(10),
			/mob/wizard2,
			/mob/elf,
			/mob/crank2,
			/mob/barbarian2,
			/mob/scorpion,
			/mob/wolf,
			/mob/goblin2,
			/mob/blue_meanie2,
			/mob/rataman2)

		if(21 to 30) return pick(
			prob(500); .(11),
			/mob/warrior2,
			/mob/dwarf2,
			/mob/centaur2,
			/mob/ghost,
			/mob/zombie)

		else return pick(
			prob(500); .(21),
			/mob/wizard3,
			/mob/blue_meanie3,
			/mob/rataman3,
			/mob/dragon,
			/mob/vampire)

	}
}
