/*
The Night Mud Universe
Author: Dan of Dantom
Email: dantom@dantom.com
Version: 1.1 (8-Jul-2000)
Version: 1.0 (21-Aug-1999)

This uses the BYOND MUD engine combined with the Night Soil combat system
as the basis for the Night Mud universe.

It might have been simpler to make the rooms on-line (in the .sav file)
but they are all encoded here instead.
*/

#include "nightmud.dm"
#include "actions.dm"

Mud/New()
	..()
	src.roomtypes.Remove(typesof(/room/soft_coded))

var
	MyAddr = "file://nightmud.dmb" //default for local access

world
	hub = "Dan.NightMud"

world/New()
	if(port)
		//MyAddr = "[world.address]:[world.port]"
		MyAddr = hub
	..()

Mud/WelcomePlayer()
	usr << "Welcome, [usr].  Pay a visit to the temple library if you don't know what is going on.  If you <em>really</em> don't know what is going on, I can give you a <a href=#hint>hint</a>.\n\n<SPAN CLASS=system>Note: This world is <b>extremely</b> experimental!  I am in the process of fine-tuning the stat system.</SPAN>  If you think it is too hard or too easy or you have any other suggestions, please let me know!  I could use some help running this world as I have a severe time shortage these days!"

Mud/WelcomeNewPlayer()
	WelcomePlayer()

	spawn //wait for player to get placed in a room
		new/obj/Weapon/rock(usr.loc)

client/Topic(href)
	if(href == "hint")
		usr << "Use direction keys to move around.  The up arrow goes north, right goes east, and so on.  To get to the library from the center of the universe, you would go north twice and then west."
	else return ..()

/************** Rooms **************/
room/soft_coded
	heap
		name = "The Heap"
		desc = "The center of the universe is a pleasant tranquil patch of grass where birds sing, crickets chirp, and the local people (in blissful ignorance) have piled a great heap of dung."
		roomid = 1   //the login room
		north_exit = .south_temple
		east_exit = .east_alley
		west_exit = .west_alley
		New()
			..()
			var/action/logout/a = new(src)
			a.SetName("sleep")
			a.desc = "curls up in a nice cozy spot and drifts off."		
	south_temple
		name = "Monks Quarters"
		desc = "Wooden benches and stone cells worn by the passage of centuries are here.  Some novice monks have etched graffiti onto a pillar."
		north_exit = .temple
		south_exit = .heap
		population = list(/mob/rat)
		New()
			var/action/graffiti = new(src)
			graffiti.SetName("read graffiti")
			graffiti.udesc = "Dan was here!  Please <a href=mailto:dan@dantom.com?subject=NightMud>report</a> bugs and suggestions."
			..()
	temple
		name = "The Temple"
		desc = "Despite the clash of cymbols, raucous chanting, and tarish clouds of incense, you feel a deep peace in this timeless place."
		north_exit = .north_temple
		south_exit = .south_temple
		east_exit = .east_temple
		west_exit = .west_temple

		Enter(O)
			if(istype(O,/obj/Food) && usr)
				usr.AddKarma(-O:karma)
			return ..()
		Exit(O)
			if(istype(O,/obj/Food) && usr)
				usr.AddKarma(2*O:karma)
			return ..()
	east_temple
		name = "Custodian's Room"
		desc = "Carved into the stone wall are depictions of a computer control room from some distant age in the past."
		west_exit = .temple
	west_temple
		name = "Temple Library"
		desc = "It smells of musty parchment here.  You can find volumes describing every corner of the known universe on these shelves."
		east_exit = .temple
		population = list(/mob/spider)
		New()
			var/action/browse/a = new(src)
			a.SetName("read introduction")
			a.desc = "grabs a scrap of parchment from the shelf."
			a.file = "introduction.html"

			a = new(src)
			a.SetName("read history")
			a.desc = "grabs a dusty scroll from the shelf."
			a.file = "history.html"

			var/action/feco = new(src)
			feco.SetName("read fecophobia")
			feco.desc = "grabs a roll of toilet paper from the shelf."
			feco.udesc = "Inscribed on this lengthy scroll: Non <a href='http://dan.byond.com/fecophobia'>fecophubus</a> carborundum est!"

			..()

	north_temple
		name = "Temple Steps"
		desc = "The temple steps emerge from the belly of an enormous stone cow."
		north_exit = .village_gate
		south_exit = .temple
		east_exit = .village_road/ne
		west_exit = .village_road/nw
	village_road
		name = "Village Road"
		ne
			west_exit = .north_temple
			south_exit = .en
		nw
			south_exit = .wn
			east_exit = .north_temple
		en
			north_exit = .ne
			south_exit = .es
			east_exit = .shop/food
		wn
			north_exit = .nw
			south_exit = .ws
			west_exit = .shop/butcher
		es
			north_exit = .en
			south_exit = .se
			west_exit = .east_alley
		ws
			north_exit = .wn
			south_exit = .sw
			east_exit = .west_alley
		se
			north_exit = .es
			west_exit = .sw
			south_exit = .shop/fortune
		sw
			north_exit = .ws
			east_exit = .se
	east_alley
		name = "Alley"
		west_exit = .heap
		east_exit = .village_road/es
		population = list(/mob/cat)
	west_alley
		name = "Alley"
		east_exit = .heap
		west_exit = .village_road/ws
		population = list(/mob/thief)
	shop
		var/shop_type
		var/shop_keeper = "shop keeper"
		proc
			Price(obj/O)
				. = round(O.Value() * 1.1 * (1 + usr.karma) + 0.99)
				if(. < 0) . = 0
			SellToUsr(obj/O)
				var/price = src.Price(O)
				if(usr.SubMoney(price))
					usr << "[src.shop_keeper] takes [price] chips and thanks you very much!"
					return 1
				usr << "You do not have [price] chip\s!"
			BuyFromUsr(obj/O)
				var/price = O.Value()
				if(src.shop_type && istype(O,src.shop_type) && price > 0)
					usr.AddMoney(price)
					usr << "[src.shop_keeper] gives you [price] chips."
					return 1
				usr << "[src.shop_keeper] won't buy \an [O].  Keep it!"
		Exit(obj/O)
			. = ..()
			if(. && isobj(O) && usr)
				. = src.SellToUsr(O)
				if(. && O.poploc == src)
					O.poptype = null
					src.Repop()
		Enter(obj/O)
			. = ..()
			if(. && isobj(O) && usr) . = src.BuyFromUsr(O)
		verb/price_list()
			set name = "price list"
			var/obj/O
			for(O in src)
				usr << "[O.name] [src.Price(O)] chip\s"

		food
			name = "Giolo's Food Shop"
			desc = "The sweet smell of incense and the soft melody of a harmonium mingle in Giolo's pleasant little shop."
			shop_type = /obj/Food
			shop_keeper = "Giolo"
			population = list(/mob/rat,/mob/rat,/obj/Food/salt,/obj/Food/garlic,/obj/Food/pickle)
			west_exit = .village_road/en
		fortune
			name = "Fortune Teller's Tent"
			desc = "Preethy's tent is slightly blackened by years of kerosene smoke.  An enourmous glass mobile slowly revolves in the center of the ceiling."
			shop_type = /obj/Food/fortune_cookie
			shop_keeper = "Preethy"
			population = list(/obj/Food/fortune_cookie)
			north_exit = .village_road/se
		butcher
			name = "Zam's Carrion Shop"
			desc = "Zam is forever bellowing from in front of his shop, \"carcasses bought and sold here!  Come get your cadaver hot or cold here!\""
			shop_type = /obj/Food/Corpse
			shop_keeper = "Zam"
			east_exit = .village_road/wn
			SellToUsr(obj/Food/O)
				. = ..()
				if(.) O.rot = 0

	village_gate
		name = "Village Gate"
		desc = "A worn stone archway marks the entrance to Central Village."
		south_exit = .north_temple
		east_exit = .summer_trail/trail1
		west_exit = .forest_trail/trail1
		north_exit = .valley_trail/trail1

	/***** Summer Pasture Trail *****/
	summer_trail
		name = "Summer Pasture Trail"
		trail1
			west_exit = .village_gate
			east_exit = .trail2
		trail2
			east_exit = .trail3
			west_exit = .trail1
		trail3
			north_exit = .summer_pasture/pasture1
			west_exit = .trail2
			south_exit = .trail4
		trail4
			north_exit = .trail3
			south_exit = .trail5
			east_exit = .summer_pasture/pasture2
		trail5
			north_exit = .trail4
			south_exit = .trail6
			west_exit = .summer_pasture/pasture3
		trail6
			north_exit = .trail5
			south_exit = .summer_pasture/pasture4
			population = list(/mob/mountain_goat)

	summer_pasture
		name = "Summer Pasture"
		desc = "You find yourself in a pleasant pasture of lush mountain grasses.  Watch out for ground bees!"
		pasture1
			south_exit = .summer_trail/trail3
			population = list(/mob/hornet,/mob/hornet,/mob/hornet)
		pasture2
			west_exit = .summer_trail/trail4
			east_exit = .herder_tent
			population = list(/mob/hornet)
		pasture3
			east_exit = .summer_trail/trail5
			population = list(/mob/hornet,/mob/crank)
		pasture4
			north_exit = .summer_trail/trail6
			south_exit = .scree
			population = list(/mob/hornet,/mob/hornet,/mob/mountain_goat)

	herder_tent
		name = "Herder's Tent"
		desc = "Looks like this tent hasn't been used for some time.  It's hard to imagine why; there's such a good view through the holes in the canvas."
		west_exit = .summer_pasture/pasture2
		population = list(/mob/spider,/mob/rat,/mob/hornet)

	scree
		name = "Scree Slope"
		desc = "Keeping one's footing is somewhat tricky on this loose gravel."
		north_exit = .summer_pasture/pasture4
		south_exit = .bolders
	bolders
		name = "Bolder Field"
		desc = "Leaping from rock to rock, you just hope there isn't anything lurking down there in the crevaces."
		population = list(/mob/spider,/mob/rat,/mob/goblin)
		north_exit = .scree
		south_exit = .snow
		east_exit = .cairn
	cairn
		name = "Rock Cairn"
		desc = "A precariously stacked pile of rocks marks the spot.  But for what purpose?"
		west_exit = .bolders
		New()
			var/action/exit/teleport/a = new(src)
			a.SetName("add rock")
			a.desc = "dissappears!"
			a.odesc = "materializes in a gust of crisp alpine air."
			a.dest = .heap
			..()
	snow
		name = "Snow Bank"
		desc = "Some rather large footprints serve as a convenient trail through the snow."
		north_exit = .bolders
		south_exit = .summit
		east_exit = .hermit
		population = list(/mob/yeti)
	summit
		name = "Summit"
		desc = "You can see most of the known universe from the top of the mountain.  Of course, that's not saying much, considering how little is known."
		north_exit = .snow
		population = list(/mob/wizard)
	hermit
		name = "Hermit's Cave"
		desc = "The hermit who lived here must have been immune to the cold.  There are icicles hanging from the ceiling where his breath condensed."
		west_exit = .snow
		population = list(/mob/crank,/mob/goblin)

		New()
			var/action/local_link/a = new(src)
			a.SetName("east")
			a.file = "caves.dmb"
			a.params = "level=5&return_addr=[MyAddr]"
			a.desc = "plummets deep into the caverns!"

			..()

	/***** Forest Trail ******/

	forest_trail
		name = "Forest Trail"
		trail1
			desc = "Donkies have been on this trail.  Well fed ones.  Watch your step!"
			east_exit = .village_gate
			west_exit = .trail2
		trail2
			south_exit = .forest_clearing/clearing1
			east_exit = .trail1
			west_exit = .trail3
		trail3
			east_exit = .trail2
			west_exit = .trail4
			north_exit = .forest_clearing/clearing2
		trail4
			east_exit = .trail3
			west_exit = .bridge
			population = list(/mob/wolf)
		trail5
			east_exit = .bridge
			west_exit = .trail6
			population = list(/mob/elf)
		trail6
			east_exit = .trail5

	bridge
		name = "Bridge"
		north_exit = .stream/stream1n
		south_exit = .stream/stream1s
		west_exit = .forest_trail/trail5
	stream
		name = "Stream"
		desc = "The stream bed stones feel smooth and inviting beneath your feet, urging you to splash along."
		stream1n
			north_exit = .stream2n
			south_exit = .bridge
		stream2n
			north_exit = .stream3n
			south_exit = .stream1n
			west_exit = .forest_clearing/clearing3
			population = list(/mob/barbarian2)
		stream3n
			desc = "You find yourself at the top of a thundering waterfall.  Don't slip!"
			south_exit = .stream2n
			population = list(/mob/crank2,/mob/crank,/mob/crank)
		stream1s
			north_exit = .bridge
			south_exit = .stream2s
			population = list(/mob/crank2,/mob/crank)
		stream2s
			north_exit = .stream1s
			south_exit = .stream3s
		stream3s
			north_exit = .stream2s
			south_exit = .stream4s
			population = list(/mob/blue_meanie2)
		stream4s
			north_exit = .stream3s
			south_exit = .stream5s
			west_exit = .streamlet
		stream5s
			north_exit = .stream4s
			south_exit = .cave/mouth

	streamlet
		name = "Streamlet"
		desc = "The waters in this little brook are warm to the touch."
		east_exit = .stream/stream4s
		west_exit = .spring
	spring
		name = "Spring"
		desc = "Steam rises from the bubbling dream-like pool."
		east_exit = .streamlet
		population = list(/mob/wizard2,/mob/wolf)

	forest_clearing
		name = "Forest Clearing"
		clearing1
			north_exit = .forest_trail/trail2
			population = list(/mob/rataman)
		clearing2
			north_exit = .woodcutter
			south_exit = .forest_trail/trail3
			population = list(/mob/skeleton,/mob/skeleton)
		clearing3
			east_exit = .stream/stream2n
			population = list(/mob/wolf,/mob/wolf,/mob/goblin2)
	woodcutter
		name = "Woodcutter's Hut"
		desc = "Strangely, the woodcutter's house is made entirely out of mud.  There's not a stick of wood in it."
		north_exit = .cellar
		south_exit = .forest_clearing/clearing2
		population = list(/mob/scorpion,/mob/rat,/mob/rat)
	cellar
		name = "Woodcutter's Cellar"
		desc = "Well, it seems like a cellar, but then again, a cellar is a lot like a tomb, isn't it?"
		south_exit = .woodcutter
		population = list(/mob/skeleton,/mob/skeleton,/mob/skeleton,/obj/Food/brown_mushroom,/obj/Food/inky_mushroom)

	cave
		mouth
			name = "Cave Mouth"
			desc = "The stream emerges from the jaws of a dark cavern."
			north_exit = .stream/stream5s
			south_exit = .passage/passage1
			population = list(/mob/barbarian2,/obj/Food/red_mushroom,/obj/Food/inky_mushroom)
		passage
			name = "Passage"

			passage1
				desc = "The smell of bat guano is intoxicating here!  You giggle."
				north_exit = .mouth
				population = list(/mob/bat,/mob/bat,/mob/bat,/mob/bat)

			New()
				var/action/local_link/a = new(src)
				a.SetName("south")
				a.file = "caves.dmb"
				a.params = "level=15&return_addr=[MyAddr]"
				a.desc = "vanishes into the gloom."

				..()

	/***** Valley Trail ******/

	valley_trail
		name = "Valley Trail"
		trail1
			desc = "From the side of the mountain here you can see mist swirling through the valley far bellow."
			north_exit = .trail2
			south_exit = .village_gate
		trail2
			north_exit = .trail3
			south_exit = .trail1
		trail3
			north_exit = .trail4
			south_exit = .trail2
			east_exit = .trail6
			population = list(/mob/elf)
		trail4
			desc = "It's rather steep here and the gravel is loose.  Be careful!"
			south_exit = .trail3
			population = list(/mob/mountain_goat)
			New()
				var/action/exit/e = new(src)
				e.SetName("north")
				e.desc = "suddenly slips and tumbles off the trail!"
				e.udesc = "Your feet slide out from under you!  Crash.  Thump.  Ouch!"
				e.dest = .ledge
				..()
		trail6
			east_exit = .campsite
			west_exit = .trail3
			south_exit = .trail7
		trail7
			north_exit = .trail6
			west_exit = .mine
			population = list(/mob/warrior2)
	mine
		name = "Mine Shaft"
		desc = "You find yourself in an old abandoned mine shaft.  It would be prudent to go no further."
		New()
			var/action/local_link/a = new(src)
			a.SetName("west")
			a.file = "caves.dmb"
			a.params = "level=30&return_addr=[MyAddr]"
			a.desc = "slips down the mine shaft!"

			..()

	ledge
		name = "Ledge"
		desc = "You find yourself on a ledge in the middle of a steep gravel cliff."
		population = list(/mob/ghost,/mob/scorpion)
		New()
			var/action/exit/ledge/e = new(src)
			e.SetName("south")
			e.dest = .valley_trail/trail4
			e.desc = "scrambles up the gravel face."
			e.udesc = "You manage to scramble back up the gravel slope."
			e.odesc = "crawls with great effort back up to the trail."
		/action/exit/ledge
			Action()
				if(usr.contents.len) usr << "The gravel can't possibly support any additional weight.  Better leave your stuff behind."
				else ..()
	campsite
		name = "Campsite"
		desc = "A circle of stones surrounds the charred remains of a small cook fire."
		west_exit = .valley_trail/trail6
		population = list(/mob/centaur2,/mob/centaur2)
